==> gemini_framework-0.2.1-py3-none-any.whl: gemini_framework/abstract/unit_module_abstract.py <==
from abc import ABC
import logging
from datetime import datetime
import numpy as np

logger = logging.getLogger(__name__)
logger.addHandler(logging.StreamHandler())
logger.setLevel(logging.INFO)


class UnitModuleAbstract(ABC):
    logger = logger
    unit = None
    loop = None
    tags = {'input': {'measured': {}, 'filtered': {}, 'calculated': {}},
            'output': {'measured': {}, 'filtered': {}, 'calculated': {}}}

    def __init__(self, unit):
        self.unit = unit

    def link(self):
        self.logger.error(
            print('Module ' + self.__class__.__name__ + ' did not implement a link method'))

    def init(self, loop):
        self.loop = loop

    def link_input(self, unit, category, tagname):
        reference = unit.tags[category][tagname]

        self.tags['input'][category][tagname] = {'external_name': reference,
                                                 'internal_name': tagname + '.' + category,
                                                 'unit_name': unit.name}

    def link_output(self, unit, category, tagname):
        reference = unit.tags[category][tagname]

        self.tags['output'][category][tagname] = {'external_name': reference,
                                                  'internal_name': tagname + '.' + category,
                                                  'unit_name': unit.name}

    def get_output_last_data_time(self, tagname):
        for category in list(self.tags['output'].keys()):
            if tagname in list(self.tags['output'][category].keys()):
                break

        time_str = self.unit.plant.database.get_internal_database_last_time_str(
            self.unit.plant.name,
            self.tags['output'][category][tagname]['unit_name'],
            self.tags['output'][category][tagname]['internal_name'])

        return time_str

    def get_input_data(self, tagname):
        for category in list(self.tags['input'].keys()):
            if tagname in list(self.tags['input'][category].keys()):
                break

        result, time = self.unit.plant.database.read_internal_database(
            self.unit.plant.name,
            self.tags['input'][category][tagname]['unit_name'],
            self.tags['input'][category][tagname]['internal_name'],
            self.loop.start_time,
            self.loop.end_time,
            self.loop.timestep)

        return time, result

    def write_output_data(self, tagname, time, result):
        for category in list(self.tags['output'].keys()):
            if tagname in list(self.tags['output'][category].keys()):
                break

        self.unit.plant.database.write_internal_database(
            self.unit.plant.name,
            self.tags['output'][category][tagname]['unit_name'],
            self.tags['output'][category][tagname]['internal_name'],
            time,
            result
        )

    @staticmethod
    def get_parameter_index(unit, timestamps):

        timestamps_unix = datetime.fromisoformat(timestamps).timestamp()

        timestamps_parameters_unix = []
        for timestamp_parameter in unit.parameters['timestamps']:
            timestamps_parameters_unix.append(
                datetime.strptime(timestamp_parameter, "%Y-%m-%d %H:%M:%S").timestamp())

        index = np.argwhere(np.array(timestamps_parameters_unix) <= timestamps_unix).max()

        return index

==> gemini_framework-0.2.3-py3-none-any.whl: gemini_framework/abstract/unit_module_abstract.py <==
from abc import ABC, abstractmethod
import logging
from datetime import datetime
import numpy as np

logger = logging.getLogger(__name__)
logger.addHandler(logging.StreamHandler())
logger.setLevel(logging.INFO)


class UnitModuleAbstract(ABC):
    logger = logger
    unit = None
    loop = None
    tags = {'input': {'measured': {}, 'filtered': {}, 'calculated': {}},
            'output': {'measured': {}, 'filtered': {}, 'calculated': {}}}

    def __init__(self, unit):
        self.unit = unit

    def link(self):
        self.logger.error(
            print('Module ' + self.__class__.__name__ + ' did not implement a link method'))

    def init(self, loop):
        self.loop = loop

    def link_input(self, unit, category, tagname):
        reference = unit.tags[category][tagname]

        self.tags['input'][category][tagname] = {'external_name': reference,
                                                 'internal_name': tagname + '.' + category,
                                                 'unit_name': unit.name}

    def link_output(self, unit, category, tagname):
        reference = unit.tags[category][tagname]

        self.tags['output'][category][tagname] = {'external_name': reference,
                                                  'internal_name': tagname + '.' + category,
                                                  'unit_name': unit.name}

    def get_output_last_data_time(self, tagname):
        for category in list(self.tags['output'].keys()):
            if tagname in list(self.tags['output'][category].keys()):
                break

        time_str = self.unit.plant.database.get_internal_database_last_time_str(
            self.unit.plant.name,
            self.tags['output'][category][tagname]['unit_name'],
            self.tags['output'][category][tagname]['internal_name'])

        return time_str

    def get_input_data(self, tagname):
        for category in list(self.tags['input'].keys()):
            if tagname in list(self.tags['input'][category].keys()):
                break

        result, time = self.unit.plant.database.read_internal_database(
            self.unit.plant.name,
            self.tags['input'][category][tagname]['unit_name'],
            self.tags['input'][category][tagname]['internal_name'],
            self.loop.start_time,
            self.loop.end_time,
            self.loop.timestep)

        return time, result

    def write_output_data(self, tagname, time, result):
        for category in list(self.tags['output'].keys()):
            if tagname in list(self.tags['output'][category].keys()):
                break

        self.unit.plant.database.write_internal_database(
            self.unit.plant.name,
            self.tags['output'][category][tagname]['unit_name'],
            self.tags['output'][category][tagname]['internal_name'],
            time,
            result
        )

    def get_parameter_index(self, unit, timestamps):

        timestamps_unix = datetime.fromisoformat(timestamps).timestamp()

        timestamps_parameters_unix = []
        for timestamp_parameter in unit.parameters['timestamps']:
            timestamps_parameters_unix.append(
                datetime.strptime(timestamp_parameter, "%Y-%m-%d %H:%M:%S").timestamp())

        index = np.argwhere(np.array(timestamps_parameters_unix) <= timestamps_unix).max()

        return index

    @abstractmethod
    def update_model_parameter(self, timestamp):
        pass
